@@ -1,18 +1,14 @@
 package PITA::Guest::Driver;
 
+use 5.008;
 use strict;
 use Carp         ();
 use File::Temp   ();
 use File::Remove ();
-use Params::Util '_INSTANCE',
-                 '_POSINT',
-                 '_HASH';
+use Params::Util qw{ _INSTANCE _POSINT _HASH };
 use PITA::XML    ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '0.40';
-}
+our $VERSION = '0.50';
 
 
 
@@ -23,9 +19,7 @@ BEGIN {
 
 sub new {
 	my $class = shift;
-
-	# Create the object
-	my $self = bless { @_ }, $class;
+	my $self  = bless { @_ }, $class;
 
 	# Were we passed the guest object
 	unless ( _INSTANCE($self->guest, 'PITA::XML::Guest') ) {
@@ -127,11 +121,11 @@ For other issues, contact the author.
 
 =head1 AUTHOR
 
-Adam Kennedy, L<http://ali.as/>, cpan@ali.as
+Adam Kennedy <adamk@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright 2005, 2006 Adam Kennedy.
+Copyright 2005 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
