@@ -3,27 +3,23 @@ package PITA::Guest::Driver::Image;
 # Provides a base class for PITA Guests that are system images.
 # For example, Qemu, VMWare, etc
 
-use 5.005;
+use 5.008;
 use strict;
-use base 'PITA::Guest::Driver';
-use Carp             ();
-use File::Path       ();
-use File::Temp       ();
-use File::Copy       ();
-use File::Remove     ();
-use File::Basename   ();
-use Storable         ();
-use Params::Util     '_INSTANCE',
-                     '_POSINT',
-                     '_STRING';
-use Config::Tiny     ();
-use Class::Inspector ();
-use PITA::POE::SupportServer ();
+use  Carp                         ();
+use  File::Path                   ();
+use  File::Temp                   ();
+use  File::Copy                   ();
+use  File::Remove                 ();
+use  File::Basename               ();
+use  Storable                     ();
+use  Params::Util                 ();
+use  Config::Tiny                 ();
+use  Class::Inspector             ();
+use  PITA::Guest::Driver          ();
+use  PITA::Guest::Server::Process ();
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '0.40';
-}
+our $VERSION = '0.50';
+our @ISA     = 'PITA::Guest::Driver';
 
 
 
@@ -55,7 +51,7 @@ sub new {
 
 	# How much memory to use
 	$self->{memory} = 256 unless $self->memory;
-	unless ( _POSINT($self->memory) ) {
+	unless ( Params::Util::_POSINT($self->memory) ) {
 		Carp::croak("Invalid memory amount (in meg) '" . $self->memory . "'");
 	}
 
@@ -70,7 +66,9 @@ sub new {
 	}
 
 	# Create the support server result files to expect
-	$self->{support_server_results} = [];
+	$self->{support_server_pinged}   = 0;
+	$self->{support_server_mirrored} = [ ];
+	$self->{support_server_results}  = [ ];
 
 	$self;
 }
@@ -107,6 +105,14 @@ sub support_server_dir {
 	$_[0]->{support_server_dir};
 }
 
+sub support_server_pinged {
+	$_[0]->{support_server_pinged};
+}
+
+sub support_server_mirrored {
+	$_[0]->{support_server_mirrored};
+}
+
 sub support_server_results {
 	$_[0]->{support_server_results};
 }
@@ -118,7 +124,7 @@ sub support_server_uri {
 	URI->new( "http://"
 		. $self->support_server_addr . ':'
 		. $self->support_server_port . '/'
-		);
+	);
 }
 
 sub perl5lib_dir {
@@ -176,6 +182,12 @@ sub ping_execute {
 sub ping_cleanup {
 	my $self = shift;
 
+	# Capture results from the support server
+	$self->support_server->finish;
+	$self->{support_server_pinged}   = $self->support_server->pinged;
+	$self->{support_server_mirrored} = $self->support_server->mirrored;
+	$self->{support_server_results}  = $self->support_server->uploaded;
+
 	# Delete the support server
 	delete $self->{support_server};
 
@@ -183,10 +195,11 @@ sub ping_cleanup {
 }
 
 sub discover {
-	$_[0]->clean_injector;
-	$_[0]->discover_prepare;
-	$_[0]->discover_execute;
-	$_[0]->discover_cleanup;
+	my $self = shift;
+	$self->clean_injector;
+	$self->discover_prepare;
+	$self->discover_execute;
+	$self->discover_cleanup;
 	return 1;
 }
 
@@ -215,20 +228,29 @@ sub discover_execute {
 	or
 	Carp::croak("Failed to execute support server");
 
-	1;
+	return 1;
 }
 
 sub discover_cleanup {
 	my $self = shift;
 
+	# Capture results from the support server
+	$self->support_server->finish;
+	$self->{support_server_pinged}   = $self->support_server->pinged;
+	$self->{support_server_mirrored} = $self->support_server->mirrored;
+	$self->{support_server_results}  = $self->support_server->uploaded;
+
+	# require Devel::Dumpvar;
+	# print STDERR Devel::Dumpvar->dump($self->support_server) . "\n";
+
 	# Get the report file contents
-	my $string = $self->support_server->http_result('/1');
-	unless ( _STRING($string) ) {
+	my $string = $self->support_server->upload('/1');
+	unless ( Params::Util::_SCALAR($string) ) {
 		Carp::croak("Discovery report was not uploaded to the support server");
 	}
 
 	# Parse into a report
-	my $report = PITA::XML::Guest->read(\$string);	
+	my $report = PITA::XML::Guest->read($string);
 	unless ( $report->platforms ) {
 		Carp::croak("Discovery report did not contain any platforms");
 	}
@@ -278,21 +300,27 @@ sub test_execute {
 	or
 	Carp::croak("Failed to execute support server");
 
-	1;
+	return 1;
 }
 
 sub test_cleanup {
 	my $self    = shift;
 	my $request = shift;
 
+	# Capture results from the support server
+	$self->support_server->finish;
+	$self->{support_server_pinged}   = $self->support_server->pinged;
+	$self->{support_server_mirrored} = $self->support_server->mirrored;
+	$self->{support_server_results}  = $self->support_server->uploaded;
+
 	# Get the report
-	my $string = $self->support_server->http_result('/' . $request->id);
+	my $string = $self->support_server->upload('/' . $request->id);
 	unless ( $string ) {
 		Carp::croak("Failed to get report " . $request->id . " from support server");
 	}
 
 	# Parse into a report
-	my $report = PITA::XML::Report->read(\$string);	
+	my $report = PITA::XML::Report->read($string);
 	unless ( $report ) {
 		Carp::croak("Discovery report did not contain any platforms");
 	}
@@ -325,26 +353,26 @@ sub prepare_task {
 	my $image_conf = Config::Tiny->new;
 	$image_conf->{_} = {
 		class      => 'PITA::Image',
-		version    => '0.40',
+		version    => '0.43',
 		server_uri => $self->support_server_uri,
-		};
+	};
 	if ( -d $self->perl5lib_dir ) {
 		$image_conf->{_}->{perl5lib} = 'perl5lib';
 	}
 
 	# Add the tasks
-	if ( _STRING($task) and $task eq 'ping' ) {
+	if ( Params::Util::_STRING($task) and $task eq 'ping' ) {
 		$image_conf->{task} = {
 			task   => 'Ping',
 			job_id => 1,
-			};
+		};
 
-	} elsif ( _STRING($task) and $task eq 'discover' ) {
+	} elsif ( Params::Util::_STRING($task) and $task eq 'discover' ) {
 		# Discovery always uses the job_id 1 (for now)
 		$image_conf->{task} = {
 			task   => 'Discover',
 			job_id => 1,
-			};
+		};
 
 		# Tell the support server to expect the report
 		$self->{support_server_results} = '/1';
@@ -355,14 +383,14 @@ sub prepare_task {
 
 		# Which testing context will we run in
 		### Don't check for error, we WANT to be undef if not a platform
-		my $platform = _INSTANCE(shift, 'PITA::XML::Platform');
+		my $platform = Params::Util::_INSTANCE(shift, 'PITA::XML::Platform');
 
 		# Set the tarball filename to be relative to current
 		my $filename     = File::Basename::basename( $request->file->filename );
 		my $tarball_from = $request->file->filename;
 		my $tarball_to   = File::Spec->catfile(
 			$self->injector_dir, $filename,
-			);
+		);
 		$request->file->{filename} = $filename;
 
 		# Copy the tarball into the injector
@@ -382,7 +410,7 @@ sub prepare_task {
 			scheme => $request->scheme,
 			path   => $platform ? $platform->path : '', # '' is default
 			config => $request_file,
-			};
+		};
 
 		# Tell the support server to expect the report
 		$self->{support_server_results} = [ "/" . $request->id ];
@@ -397,7 +425,7 @@ sub prepare_task {
 		Carp::croak("Failed to write config to $image_file");
 	}
 
-	1;
+	return 1;
 }
 
 # Copy in the perl5lib modules
@@ -422,23 +450,26 @@ sub prepare_perl5lib {
 			or die "Failed to copy $from to $to";
 	}
 
-	1;
+	return 1;
 }
 
 sub clean_injector {
-	my $self     = shift;
+	my $self = shift;
+
+	# Scan for stuff in the injector
 	my $injector = $self->injector_dir;
 	opendir( INJECTOR, $injector ) or die "opendir: $!";
 	my @files = readdir( INJECTOR );
 	closedir( INJECTOR );
 
-	# Delete them
+	# Delete it all
 	foreach my $f ( File::Spec->no_upwards(@files) ) {
 		my $path = File::Spec->catfile( $injector, $f );
-		File::Remove::remove( \1, $path ) or die "Failed to remove $f from injector directory";	
+		File::Remove::remove( \1, $path ) and next;
+		die "Failed to remove $f from injector directory";
 	}
 
-	1;
+	return 1;
 }
 
 
