@@ -3,6 +3,7 @@ package PITA::Host;
 # Implements a single PITA Testing Host.
 # Responsible for managing images and processing Requests
 
+use 5.008;
 use strict;
 use Carp             ();
 use File::Spec       ();
@@ -12,10 +13,7 @@ use Archive::Extract ();
 
 use constant FFR => 'File::Find::Rule';
 
-use vars qw{$VERSION};
-BEGIN {
-	$VERSION = '0.40';
-}
+our $VERSION = '0.50';
 
 
 
@@ -76,15 +74,16 @@ sub image_cache_quota {
 # Image and Cache Management
 
 sub image_extract {
-	my ($self, $name) = @_;
+	my $self = shift;
+	my $name = shift;
 
 	# What are we extracting to where
 	my $from = File::Spec->catfile(
 		$self->image_store, "$name.img.gz",
-		);
+	);
 	my $to = File::Spec->catfile(
 		$self->image_cache, "$name.img",
-		);
+	);
 
 	# Extract the compressed image
 	local $Archive::Extract::PREFER_BIN = 1;
@@ -100,7 +99,7 @@ sub image_extract {
 }
 
 sub image_cache_clear {
-	my $self  = shift;
+	my $self = shift;
 
 	# Find all image files
 	my @files = FFR->file
